@@ -84,7 +84,7 @@ framem.append(nm);
          QActionGroup *gr4=new QActionGroup(fsk);
 
          QMenu *core=new QMenu(tr("Core"));
-         QStringList cores=QStringList()<<"psx4m"<<"gles"<<"pcsx";
+         QStringList cores=QStringList()<<"psx4m"<<"psx4m-gles"<<"pcsx";
          for (int i=0;i<cores.count();i++){
              QAction *nm=core->addAction(cores.at(i),this,SLOT(set_core()));
              nm->setActionGroup(gr4);
